==> haskell-path-io-1.3.3-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path-io
version: 1.3.3
id: path-io-1.3.3-9y2ZAmmH7JWFlCY8mqxzwf
key: path-io-1.3.3-9y2ZAmmH7JWFlCY8mqxzwf
license: BSD3
maintainer: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/path-io
synopsis: Interface to ‘directory’ package for users of ‘path’
description:
    Interface to ‘directory’ package for users of ‘path’.
category: System, Filesystem
author: Mark Karpov <markkarpov92@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Path.IO
abi: 77607463bc4fc86c0b3dae1529dbb66b
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/path-io-1.3.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/path-io-1.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/path-io-1.3.3
hs-libraries: HSpath-io-1.3.3-9y2ZAmmH7JWFlCY8mqxzwf
depends:
    base-4.10.0.0 containers-0.5.10.2 directory-1.3.0.2
    dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6 filepath-1.4.1.2
    path-0.6.1-3vYPgWREPZf5twNYNrl9DA
    temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo time-1.8.0.2
    transformers-0.5.2.0 unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
             directory-1.3.0.2=f0be8e5bd351f97ab9c9e693d2eba4ad
             dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q=97435ce23ff4e4560f559d3afbbee81e
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=62278cb6808dfdd4ea4dbd9b537b44e9
             filepath-1.4.1.2=30ad74f2069d36b2d0af3972630d4ac4
             path-0.6.1-3vYPgWREPZf5twNYNrl9DA=9c95bb225f9f4aec1d91add47ea8c59c
             temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo=ba806cd7fa58c88cefcf360552466b99
             time-1.8.0.2=3f789f9c9fc88790a10579b55c2f0b4f
             transformers-0.5.2.0=9705988bf0172d3bbbcdcaf65e1d842a
             unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp=f0e3615d16ccc9a099618a4b1bfc9d59
haddock-interfaces: /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html: /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-io-1.3.3-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path-io
version: 1.3.3
id: path-io-1.3.3-JoEcxLCcIIoLOvZgWCtoF5
key: path-io-1.3.3-JoEcxLCcIIoLOvZgWCtoF5
license: BSD3
maintainer: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/path-io
synopsis: Interface to ‘directory’ package for users of ‘path’
description:
    Interface to ‘directory’ package for users of ‘path’.
category: System, Filesystem
author: Mark Karpov <markkarpov92@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Path.IO
abi: f65e0996458a1cec69a02252abe99ec0
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/path-io-1.3.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/path-io-1.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/path-io-1.3.3
hs-libraries: HSpath-io-1.3.3-JoEcxLCcIIoLOvZgWCtoF5
depends:
    base-4.10.0.0 containers-0.5.10.2 directory-1.3.0.2
    dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6 filepath-1.4.1.2
    path-0.6.1-F7dXkjr3RauIWw3mbJNf6I
    temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo time-1.8.0.2
    transformers-0.5.2.0 unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
             directory-1.3.0.2=f0be8e5bd351f97ab9c9e693d2eba4ad
             dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q=97435ce23ff4e4560f559d3afbbee81e
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=62278cb6808dfdd4ea4dbd9b537b44e9
             filepath-1.4.1.2=30ad74f2069d36b2d0af3972630d4ac4
             path-0.6.1-F7dXkjr3RauIWw3mbJNf6I=f632b1d5318de1a440fed3a30552db3e
             temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo=ba806cd7fa58c88cefcf360552466b99
             time-1.8.0.2=3f789f9c9fc88790a10579b55c2f0b4f
             transformers-0.5.2.0=9705988bf0172d3bbbcdcaf65e1d842a
             unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp=f0e3615d16ccc9a099618a4b1bfc9d59
haddock-interfaces: /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html: /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
